SetTitleDetails class

Constructors

SetTitleDetails({required String title, int? tabId})
SetTitleDetails.fromJS(SetTitleDetails _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabId ↔ int?
Limits the change to when a particular tab is selected. Automatically resets when the tab is closed.
getter/setter pair
title ↔ String
The string the action should display when moused over.
getter/setter pair
toJS → SetTitleDetails
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited