DeviceProperties class

Constructors

DeviceProperties({int? level})
DeviceProperties.fromJS(DeviceProperties _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
level ↔ int?
The audio device's desired sound level. Defaults to the device's current sound level.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → DeviceProperties
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited