MuteChangedEvent class

Constructors

MuteChangedEvent({required StreamType streamType, required bool isMuted})
MuteChangedEvent.fromJS(MuteChangedEvent _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMuted ↔ bool
Whether or not the stream is now muted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamType ↔ StreamType
The type of the stream for which the mute value changed. The updated mute value applies to all devices with this stream type.
getter/setter pair
toJS → MuteChangedEvent
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited