SignRequest class

Constructors

SignRequest({required int signRequestId, required ByteBuffer digest, required Hash hash, required ByteBuffer certificate})
SignRequest.fromJS(SignRequest _wrapped)

Properties

certificate ↔ ByteBuffer
The DER encoding of a X.509 certificate. The extension must sign digest using the associated private key.
getter/setter pair
digest ↔ ByteBuffer
The digest that must be signed.
getter/setter pair
hash ↔ Hash
Refers to the hash algorithm that was used to create digest.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signRequestId ↔ int
The unique ID to be used by the extension should it need to call a method that requires it, e.g. requestPin.
getter/setter pair
toJS → SignRequest
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited