SignatureRequest class

Constructors

SignatureRequest({required int signRequestId, required ByteBuffer input, required Algorithm algorithm, required ByteBuffer certificate})
SignatureRequest.fromJS(SignatureRequest _wrapped)

Properties

algorithm ↔ Algorithm
Signature algorithm to be used.
getter/setter pair
certificate ↔ ByteBuffer
The DER encoding of a X.509 certificate. The extension must sign input using the associated private key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
input ↔ ByteBuffer
Data to be signed. Note that the data is not hashed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signRequestId ↔ int
Request identifier to be passed to reportSignature.
getter/setter pair
toJS → SignatureRequest
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited