MatchedRule class

Constructors

MatchedRule({required int ruleId, required String rulesetId})
MatchedRule.fromJS(MatchedRule _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ruleId ↔ int
A matching rule's ID.
getter/setter pair
rulesetId ↔ String
ID of the Ruleset this rule belongs to. For a rule originating from the set of dynamic rules, this will be equal to DYNAMIC_RULESET_ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → MatchedRule
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited