MatchedRulesFilter class

Constructors

MatchedRulesFilter({int? tabId, double? minTimeStamp})
MatchedRulesFilter.fromJS(MatchedRulesFilter _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
minTimeStamp ↔ double?
If specified, only matches rules after the given timestamp.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabId ↔ int?
If specified, only matches rules for the given tab. Matches rules not associated with any active tab if set to -1.
getter/setter pair
toJS → MatchedRulesFilter
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited