RegexOptions class

Constructors

RegexOptions({required String regex, bool? isCaseSensitive, bool? requireCapturing})
RegexOptions.fromJS(RegexOptions _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCaseSensitive ↔ bool?
Whether the regex specified is case sensitive. Default is true.
getter/setter pair
regex ↔ String
The regular expresson to check.
getter/setter pair
requireCapturing ↔ bool?
Whether the regex specified requires capturing. Capturing is only required for redirect rules which specify a regexSubstition action. The default is false.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → RegexOptions
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited