RequestMethod enum

This describes the HTTP request method of a network request.

Inheritance
Available extensions

Values

connect → const RequestMethod
const RequestMethod('connect')
delete → const RequestMethod
const RequestMethod('delete')
get → const RequestMethod
const RequestMethod('get')
const RequestMethod('head')
options → const RequestMethod
const RequestMethod('options')
patch → const RequestMethod
const RequestMethod('patch')
post → const RequestMethod
const RequestMethod('post')
put → const RequestMethod
const RequestMethod('put')
other → const RequestMethod
const RequestMethod('other')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → String
no setter
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJS(String value) → RequestMethod

Constants

values → const List<RequestMethod>
A constant List of the values in this enum, in order of their declaration.