RuleAction class

Constructors

RuleAction({required RuleActionType type, Redirect? redirect, List<ModifyHeaderInfo>? requestHeaders, List<ModifyHeaderInfo>? responseHeaders})
RuleAction.fromJS(RuleAction _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
redirect ↔ Redirect?
Describes how the redirect should be performed. Only valid for redirect rules.
getter/setter pair
requestHeaders ↔ List<ModifyHeaderInfo>?
The request headers to modify for the request. Only valid if RuleActionType is "modifyHeaders".
getter/setter pair
responseHeaders ↔ List<ModifyHeaderInfo>?
The response headers to modify for the request. Only valid if RuleActionType is "modifyHeaders".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → RuleAction
no setter
type ↔ RuleActionType
The type of action to perform.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited