Ruleset class

Constructors

Ruleset({required String id, required String path, required bool enabled})
Ruleset.fromJS(Ruleset _wrapped)

Properties

enabled ↔ bool
Whether the ruleset is enabled by default.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
A non-empty string uniquely identifying the ruleset. IDs beginning with '_' are reserved for internal use.
getter/setter pair
path ↔ String
The path of the JSON ruleset relative to the extension directory.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → Ruleset
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited