URLTransform class

Constructors

URLTransform({String? scheme, String? host, String? port, String? path, String? query, QueryTransform? queryTransform, String? fragment, String? username, String? password})
URLTransform.fromJS(URLTransform _wrapped)

Properties

fragment ↔ String?
The new fragment for the request. Should be either empty, in which case the existing fragment is cleared; or should begin with '#'.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
The new host for the request.
getter/setter pair
password ↔ String?
The new password for the request.
getter/setter pair
path ↔ String?
The new path for the request. If empty, the existing path is cleared.
getter/setter pair
port ↔ String?
The new port for the request. If empty, the existing port is cleared.
getter/setter pair
query ↔ String?
The new query for the request. Should be either empty, in which case the existing query is cleared; or should begin with '?'.
getter/setter pair
queryTransform ↔ QueryTransform?
Add, remove or replace query key-value pairs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme ↔ String?
The new scheme for the request. Allowed values are "http", "https", "ftp" and "chrome-extension".
getter/setter pair
toJS → URLTransform
no setter
username ↔ String?
The new username for the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited