UpdateRuleOptions class

Constructors

UpdateRuleOptions({List<int>? removeRuleIds, List<Rule>? addRules})
UpdateRuleOptions.fromJS(UpdateRuleOptions _wrapped)

Properties

addRules ↔ List<Rule>?
Rules to add.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
removeRuleIds ↔ List<int>?
IDs of the rules to remove. Any invalid IDs will be ignored.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → UpdateRuleOptions
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited