GetContentResult class

Constructors

GetContentResult({required String content, required String encoding})

Properties

content → String
Content of the resource (potentially encoded).
final
encoding → String
Empty if the content is not encoded, encoding name otherwise. Currently, only base64 is supported.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited