BooleanDelta class

Constructors

BooleanDelta({bool? previous, bool? current})
BooleanDelta.fromJS(BooleanDelta _wrapped)

Properties

current ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
previous ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → BooleanDelta
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited