DownloadQuery class

Constructors

DownloadQuery({List<String>? query, String? startedBefore, String? startedAfter, String? endedBefore, String? endedAfter, double? totalBytesGreater, double? totalBytesLess, String? filenameRegex, String? urlRegex, String? finalUrlRegex, int? limit, List<String>? orderBy, int? id, String? url, String? finalUrl, String? filename, DangerType? danger, String? mime, String? startTime, String? endTime, State? state, bool? paused, InterruptReason? error, double? bytesReceived, double? totalBytes, double? fileSize, bool? exists})
DownloadQuery.fromJS(DownloadQuery _wrapped)

Properties

bytesReceived ↔ double?
Number of bytes received so far from the host, without considering file compression.
getter/setter pair
danger ↔ DangerType?
Indication of whether this download is thought to be safe or known to be suspicious.
getter/setter pair
endedAfter ↔ String?
Limits results to DownloadItem that ended after the given ms since the epoch.
getter/setter pair
endedBefore ↔ String?
Limits results to DownloadItem that ended before the given ms since the epoch.
getter/setter pair
endTime ↔ String?
The time when the download ended in ISO 8601 format.
getter/setter pair
error ↔ InterruptReason?
Why a download was interrupted.
getter/setter pair
exists ↔ bool?
Whether the downloaded file exists;
getter/setter pair
filename ↔ String?
Absolute local path.
getter/setter pair
filenameRegex ↔ String?
Limits results to DownloadItem whose filename matches the given regular expression.
getter/setter pair
fileSize ↔ double?
Number of bytes in the whole file post-decompression, or -1 if unknown.
getter/setter pair
finalUrl ↔ String?
The absolute URL that this download is being made from, after all redirects.
getter/setter pair
finalUrlRegex ↔ String?
Limits results to DownloadItem whose finalUrl matches the given regular expression.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The id of the DownloadItem to query.
getter/setter pair
limit ↔ int?
The maximum number of matching DownloadItem returned. Defaults to 1000. Set to 0 in order to return all matching DownloadItem. See search for how to page through results.
getter/setter pair
mime ↔ String?
The file's MIME type.
getter/setter pair
orderBy ↔ List<String>?
Set elements of this array to DownloadItem properties in order to sort search results. For example, setting orderBy=['startTime'] sorts the DownloadItem by their start time in ascending order. To specify descending order, prefix with a hyphen: '-startTime'.
getter/setter pair
paused ↔ bool?
True if the download has stopped reading data from the host, but kept the connection open.
getter/setter pair
query ↔ List<String>?
This array of search terms limits results to DownloadItem whose filename or url or finalUrl contain all of the search terms that do not begin with a dash '-' and none of the search terms that do begin with a dash.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAfter ↔ String?
Limits results to DownloadItem that started after the given ms since the epoch.
getter/setter pair
startedBefore ↔ String?
Limits results to DownloadItem that started before the given ms since the epoch.
getter/setter pair
startTime ↔ String?
The time when the download began in ISO 8601 format.
getter/setter pair
state ↔ State?
Indicates whether the download is progressing, interrupted, or complete.
getter/setter pair
toJS → DownloadQuery
no setter
totalBytes ↔ double?
Number of bytes in the whole file, without considering file compression, or -1 if unknown.
getter/setter pair
totalBytesGreater ↔ double?
Limits results to DownloadItem whose totalBytes is greater than the given integer.
getter/setter pair
totalBytesLess ↔ double?
Limits results to DownloadItem whose totalBytes is less than the given integer.
getter/setter pair
url ↔ String?
The absolute URL that this download initiated from, before any redirects.
getter/setter pair
urlRegex ↔ String?
Limits results to DownloadItem whose url matches the given regular expression.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited