StringDelta class

Constructors

StringDelta({String? previous, String? current})
StringDelta.fromJS(StringDelta _wrapped)

Properties

current ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
previous ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → StringDelta
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited