UiOptions class

Constructors

UiOptions({required bool enabled})
UiOptions.fromJS(UiOptions _wrapped)

Properties

enabled ↔ bool
Enable or disable the download UI.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → UiOptions
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited