OnRequestExternalEvent class
Constructors
-
OnRequestExternalEvent({required Object? request, required MessageSender sender, required JSFunction<
Function> sendResponse})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → Object?
-
The request sent by the calling script.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → MessageSender
-
final
-
sendResponse
→ JSFunction<
Function> -
Function to call when you have a response. The argument should be any
JSON-ifiable object, or undefined if there is no response.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited