AddWatcherRequestedOptions class

Constructors

AddWatcherRequestedOptions({required String fileSystemId, required int requestId, required String entryPath, required bool recursive})
AddWatcherRequestedOptions.fromJS(AddWatcherRequestedOptions _wrapped)

Properties

entryPath ↔ String
The path of the entry to be observed.
getter/setter pair
fileSystemId ↔ String
The identifier of the file system related to this operation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
recursive ↔ bool
Whether observing should include all child entries recursively. It can be true for directories only.
getter/setter pair
requestId ↔ int
The unique identifier of this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → AddWatcherRequestedOptions
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited