DeleteEntryRequestedOptions class

Constructors

DeleteEntryRequestedOptions({required String fileSystemId, required int requestId, required String entryPath, required bool recursive})
DeleteEntryRequestedOptions.fromJS(DeleteEntryRequestedOptions _wrapped)

Properties

entryPath ↔ String
The path of the entry to be deleted.
getter/setter pair
fileSystemId ↔ String
The identifier of the file system related to this operation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
recursive ↔ bool
Whether the operation is recursive (for directories only).
getter/setter pair
requestId ↔ int
The unique identifier of this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → DeleteEntryRequestedOptions
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited