EntryMetadata class

Constructors

EntryMetadata({bool? isDirectory, String? name, double? size, JSAny? modificationTime, String? mimeType, String? thumbnail, CloudIdentifier? cloudIdentifier})
EntryMetadata.fromJS(EntryMetadata _wrapped)

Properties

cloudIdentifier ↔ CloudIdentifier?
Cloud storage representation of this entry. Must be provided if requested in options and the file is backed by cloud storage. For local files not backed by cloud storage, it should be undefined when requested.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDirectory ↔ bool?
True if it is a directory. Must be provided if requested in options.
getter/setter pair
mimeType ↔ String?
Mime type for the entry. Always optional, but should be provided if requested in options.
getter/setter pair
modificationTime ↔ JSAny?
The last modified time of this entry. Must be provided if requested in options.
getter/setter pair
name ↔ String?
Name of this entry (not full path name). Must not contain '/'. For root it must be empty. Must be provided if requested in options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ double?
File size in bytes. Must be provided if requested in options.
getter/setter pair
thumbnail ↔ String?
Thumbnail image as a data URI in either PNG, JPEG or WEBP format, at most 32 KB in size. Optional, but can be provided only when explicitly requested by the onGetMetadataRequested event.
getter/setter pair
toJS → EntryMetadata
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited