FileSystemInfo class

Constructors

FileSystemInfo({required String fileSystemId, required String displayName, required bool writable, required int openedFilesLimit, required List<OpenedFile> openedFiles, bool? supportsNotifyTag, required List<Watcher> watchers})
FileSystemInfo.fromJS(FileSystemInfo _wrapped)

Properties

displayName ↔ String
A human-readable name for the file system.
getter/setter pair
fileSystemId ↔ String
The identifier of the file system.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
openedFiles ↔ List<OpenedFile>
List of currently opened files.
getter/setter pair
openedFilesLimit ↔ int
The maximum number of files that can be opened at once. If 0, then not limited.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsNotifyTag ↔ bool?
Whether the file system supports the tag field for observing directories.
getter/setter pair
toJS → FileSystemInfo
no setter
watchers ↔ List<Watcher>
List of watchers.
getter/setter pair
writable ↔ bool
Whether the file system supports operations which may change contents of the file system (such as creating, deleting or writing to files).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited