GetMetadataRequestedOptions class

Constructors

GetMetadataRequestedOptions({required String fileSystemId, required int requestId, required String entryPath, required bool isDirectory, required bool name, required bool size, required bool modificationTime, required bool mimeType, required bool thumbnail, required bool cloudIdentifier})
GetMetadataRequestedOptions.fromJS(GetMetadataRequestedOptions _wrapped)

Properties

cloudIdentifier ↔ bool
Set to true if cloudIdentifier value is requested.
getter/setter pair
entryPath ↔ String
The path of the entry to fetch metadata about.
getter/setter pair
fileSystemId ↔ String
The identifier of the file system related to this operation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDirectory ↔ bool
Set to true if is_directory value is requested.
getter/setter pair
mimeType ↔ bool
Set to true if mimeType value is requested.
getter/setter pair
modificationTime ↔ bool
Set to true if modificationTime value is requested.
getter/setter pair
name ↔ bool
Set to true if name value is requested.
getter/setter pair
requestId ↔ int
The unique identifier of this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ bool
Set to true if size value is requested.
getter/setter pair
thumbnail ↔ bool
Set to true if thumbnail value is requested.
getter/setter pair
toJS → GetMetadataRequestedOptions
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited