OpenedFile class

Constructors

OpenedFile({required int openRequestId, required String filePath, required OpenFileMode mode})
OpenedFile.fromJS(OpenedFile _wrapped)

Properties

filePath ↔ String
The path of the opened file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ OpenFileMode
Whether the file was opened for reading or writing.
getter/setter pair
openRequestId ↔ int
A request ID to be be used by consecutive read/write and close requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → OpenedFile
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited