WriteFileRequestedOptions class

Constructors

WriteFileRequestedOptions({required String fileSystemId, required int requestId, required int openRequestId, required double offset, required ByteBuffer data})
WriteFileRequestedOptions.fromJS(WriteFileRequestedOptions _wrapped)

Properties

data ↔ ByteBuffer
Buffer of bytes to be written to the file.
getter/setter pair
fileSystemId ↔ String
The identifier of the file system related to this operation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offset ↔ double
Position in the file (in bytes) to start writing the bytes from.
getter/setter pair
openRequestId ↔ int
A request ID used to open the file.
getter/setter pair
requestId ↔ int
The unique identifier of this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → WriteFileRequestedOptions
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited