DeleteRangeRange class

Constructors

DeleteRangeRange({required double startTime, required double endTime})
DeleteRangeRange.fromJS(DeleteRangeRange _wrapped)

Properties

endTime ↔ double
Items added to history before this date, represented in milliseconds since the epoch.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ double
Items added to history after this date, represented in milliseconds since the epoch.
getter/setter pair
toJS → DeleteRangeRange
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited