SearchQuery class

Constructors

SearchQuery({required String text, double? startTime, double? endTime, int? maxResults})
SearchQuery.fromJS(SearchQuery _wrapped)

Properties

endTime ↔ double?
Limit results to those visited before this date, represented in milliseconds since the epoch.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxResults ↔ int?
The maximum number of results to retrieve. Defaults to 100.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ double?
Limit results to those visited after this date, represented in milliseconds since the epoch. If not specified, this defaults to 24 hours in the past.
getter/setter pair
text ↔ String
A free-text query to the history service. Leave empty to retrieve all pages.
getter/setter pair
toJS → SearchQuery
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited