TransitionType enum

The transition type for this visit from its referrer.

Inheritance
Available extensions

Values

const TransitionType('link')
typed → const TransitionType
const TransitionType('typed')
autoBookmark → const TransitionType
const TransitionType('auto_bookmark')
autoSubframe → const TransitionType
const TransitionType('auto_subframe')
manualSubframe → const TransitionType
const TransitionType('manual_subframe')
generated → const TransitionType
const TransitionType('generated')
autoToplevel → const TransitionType
const TransitionType('auto_toplevel')
formSubmit → const TransitionType
const TransitionType('form_submit')
reload → const TransitionType
const TransitionType('reload')
keyword → const TransitionType
const TransitionType('keyword')
keywordGenerated → const TransitionType
const TransitionType('keyword_generated')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → String
no setter
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJS(String value) → TransitionType

Constants

values → const List<TransitionType>
A constant List of the values in this enum, in order of their declaration.