VerificationDetails class

Constructors

VerificationDetails({required List<ByteBuffer> serverCertificateChain, required String hostname})
VerificationDetails.fromJS(VerificationDetails _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String
The hostname of the server to verify the certificate for, e.g. the server that presented the serverCertificateChain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverCertificateChain ↔ List<ByteBuffer>
Each chain entry must be the DER encoding of a X.509 certificate, the first entry must be the server certificate and each entry must certify the entry preceding it.
getter/setter pair
toJS → VerificationDetails
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited