SubmitJobRequest class

Constructors

SubmitJobRequest({required PrintJob job, String? documentBlobUuid})
SubmitJobRequest.fromJS(SubmitJobRequest _wrapped)

Properties

documentBlobUuid ↔ String?
Used internally to store the blob uuid after parameter customization and shouldn't be populated by the extension.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
job ↔ PrintJob
The print job to be submitted. The only supported content type is "application/pdf", and the Cloud Job Ticket shouldn't include FitToPageTicketItem, PageRangeTicketItem, ReverseOrderTicketItem and VendorTicketItem fields since they are irrelevant for native printing. All other fields must be present.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → SubmitJobRequest
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited