postMessage property

JSFunction<Function> get postMessage

Send a message to the other end of the port. If the port is disconnected, an error is thrown.

Implementation

JSFunction get postMessage => _wrapped.postMessage;
set postMessage (JSFunction<Function> v)

Implementation

set postMessage(JSFunction v) {
  _wrapped.postMessage = v;
}