ChromeSidePanel class

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAvailable → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOptions(GetPanelOptions options) → Future<PanelOptions>
Returns the active panel configuration. |options|: Specifies the context to return the configuration for. |callback|: Called with the active panel configuration.
getPanelBehavior() → Future<PanelBehavior>
Returns the extension's current side panel behavior. |callback|: Called with the extension's side panel behavior.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(OpenOptions options) → Future<void>
Opens the side panel for the extension. This may only be called in response to a user action. |options|: Specifies the context in which to open the side panel. |callback|: Called when the side panel has been opened.
setOptions(PanelOptions options) → Future<void>
Configures the side panel. |options|: The configuration options to apply to the panel. |callback|: Invoked when the options have been set.
setPanelBehavior(PanelBehavior behavior) → Future<void>
Configures the extension's side panel behavior. This is an upsert operation. |behavior|: The new behavior to be set. |callback|: Called when the new behavior has been set.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited