Bounds class

Constructors

Bounds({required int left, required int top, required int width, required int height})
Bounds.fromJS(Bounds _wrapped)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
The height of the display in pixels.
getter/setter pair
left ↔ int
The x-coordinate of the upper-left corner.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → Bounds
no setter
top ↔ int
The y-coordinate of the upper-left corner.
getter/setter pair
width ↔ int
The width of the display in pixels.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited