Insets class

Constructors

Insets({required int left, required int top, required int right, required int bottom})
Insets.fromJS(Insets _wrapped)

Properties

bottom ↔ int
The y-axis distance from the bottom bound.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ int
The x-axis distance from the left bound.
getter/setter pair
The x-axis distance from the right bound.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → Insets
no setter
top ↔ int
The y-axis distance from the top bound.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited