ConnectInfo class

Constructors

ConnectInfo({String? name, int? frameId, String? documentId})
ConnectInfo.fromJS(ConnectInfo _wrapped)

Properties

documentId ↔ String?
Open a port to a specific document identified by documentId instead of all frames in the tab.
getter/setter pair
frameId ↔ int?
Open a port to a specific frame identified by frameId instead of all frames in the tab.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Is passed into onConnect for content scripts that are listening for the connection event.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → ConnectInfo
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited