OnAttachedEvent class

Constructors

OnAttachedEvent({required int tabId, required OnAttachedAttachInfo attachInfo})

Properties

attachInfo → OnAttachedAttachInfo
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited