UIEvent enum

The enum is used by the platform to indicate the event that triggered onUIEvent.

Inheritance
Available extensions

Values

showAddDialog → const UIEvent

Requests that the VPN client show the add configuration dialog box to the user.

const UIEvent('showAddDialog')
showConfigureDialog → const UIEvent

Requests that the VPN client show the configuration settings dialog box to the user.

const UIEvent('showConfigureDialog')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → String
no setter
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJS(String value) → UIEvent

Constants

values → const List<UIEvent>
A constant List of the values in this enum, in order of their declaration.