GetAllFramesCallbackDetails class

Constructors

GetAllFramesCallbackDetails({required bool errorOccurred, required int processId, required int frameId, required int parentFrameId, required String url, required String documentId, String? parentDocumentId, required DocumentLifecycle documentLifecycle, required FrameType frameType})
GetAllFramesCallbackDetails.fromJS(GetAllFramesCallbackDetails _wrapped)

Properties

documentId ↔ String
A UUID of the document loaded.
getter/setter pair
documentLifecycle ↔ DocumentLifecycle
The lifecycle the document is in.
getter/setter pair
errorOccurred ↔ bool
True if the last navigation in this frame was interrupted by an error, i.e. the onErrorOccurred event fired.
getter/setter pair
frameId ↔ int
The ID of the frame. 0 indicates that this is the main frame; a positive value indicates the ID of a subframe.
getter/setter pair
frameType ↔ FrameType
The type of frame the navigation occurred in.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parentDocumentId ↔ String?
A UUID of the parent document owning this frame. This is not set if there is no parent.
getter/setter pair
parentFrameId ↔ int
The ID of the parent frame, or -1 if this is the main frame.
getter/setter pair
processId ↔ int
The ID of the process that runs the renderer for this frame.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJS → GetAllFramesCallbackDetails
no setter
url ↔ String
The URL currently associated with this frame.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited