OnHistoryStateUpdatedDetails class

Constructors

OnHistoryStateUpdatedDetails({required int tabId, required String url, required int processId, required int frameId, required int parentFrameId, required TransitionType transitionType, required List<TransitionQualifier> transitionQualifiers, required double timeStamp, required String documentId, String? parentDocumentId, required DocumentLifecycle documentLifecycle, required FrameType frameType})
OnHistoryStateUpdatedDetails.fromJS(OnHistoryStateUpdatedDetails _wrapped)

Properties

documentId ↔ String
A UUID of the document loaded.
getter/setter pair
documentLifecycle ↔ DocumentLifecycle
The lifecycle the document is in.
getter/setter pair
frameId ↔ int
0 indicates the navigation happens in the tab content window; a positive value indicates navigation in a subframe. Frame IDs are unique within a tab.
getter/setter pair
frameType ↔ FrameType
The type of frame the navigation occurred in.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parentDocumentId ↔ String?
A UUID of the parent document owning this frame. This is not set if there is no parent.
getter/setter pair
parentFrameId ↔ int
The ID of the parent frame, or -1 if this is the main frame.
getter/setter pair
processId ↔ int
The ID of the process that runs the renderer for this frame.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabId ↔ int
The ID of the tab in which the navigation occurs.
getter/setter pair
timeStamp ↔ double
The time when the navigation was committed, in milliseconds since the epoch.
getter/setter pair
toJS → OnHistoryStateUpdatedDetails
no setter
transitionQualifiers ↔ List<TransitionQualifier>
A list of transition qualifiers.
getter/setter pair
transitionType ↔ TransitionType
Cause of the navigation.
getter/setter pair
url ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited